DescriptionThis change reduces startup time of a minimal gadget
from ~1800ms to ~1100ms in Chrome Beta (16.0)
This change is mostly about speeding up cajaVM.def(), mainly
by changing a recursive implementation to an iterative one.
cajaVM.def also ends up invoking
Object.prototype.ownKeys___
whitelistAll
and this change speeds those up by using Object.keys when
possible, and inlining some tests.
Patch Set 1 #Patch Set 2 : faster es53: cajaVM.def edition #
Total comments: 1
MessagesTotal messages: 3
|
||||||||||||||||||||||||||||